summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvastext_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvastext_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvastext_imp.cpp124
1 files changed, 62 insertions, 62 deletions
diff --git a/kjsembed/qtbindings/qcanvastext_imp.cpp b/kjsembed/qtbindings/qcanvastext_imp.cpp
index 44db9795..bb1c00ce 100644
--- a/kjsembed/qtbindings/qcanvastext_imp.cpp
+++ b/kjsembed/qtbindings/qcanvastext_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QCanvasTextImp::QCanvasTextImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQCanvasTextImp::TQCanvasTextImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QCanvasTextImp::~QCanvasTextImp()
+TTQCanvasTextImp::~TQCanvasTextImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QCanvasTextImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasTextImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QCanvasTextImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &objec
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasTextImp *meth = new QCanvasTextImp( exec, methods[idx].id );
+ TQCanvasTextImp *meth = new TQCanvasTextImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QCanvasTextImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &objec
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -80,11 +80,11 @@ void QCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasTextImp *meth = new QCanvasTextImp( exec, methods[idx].id );
+ TQCanvasTextImp *meth = new TQCanvasTextImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -93,87 +93,87 @@ void QCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TQCanvasText pointer from an Object.
*/
-TQCanvasText *QCanvasTextImp::toQCanvasText( KJS::Object &self )
+TTQCanvasText *TQCanvasTextImp::toTQCanvasText( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQCanvasText *>( obj );
+ return dynamic_cast<TTQCanvasText *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQCanvasText" )
+ if ( op->typeName() != "TTQCanvasText" )
return 0;
- return op->toNative<TQCanvasText>();
+ return op->toNative<TTQCanvasText>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QCanvasTextImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasTextImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QCanvasText_1:
- return QCanvasText_1( exec, args );
+ return TQCanvasText_1( exec, args );
break;
case Constructor_QCanvasText_2:
- return QCanvasText_2( exec, args );
+ return TQCanvasText_2( exec, args );
break;
case Constructor_QCanvasText_3:
- return QCanvasText_3( exec, args );
+ return TQCanvasText_3( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QCanvasTextCons has no constructor with id '%1'.").arg(id);
+ TTQString msg = i18n("TQCanvasTextCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QCanvasTextImp::QCanvasText_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasTextImp::TQCanvasText_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter TQCanvas *
return KJS::Object();
- TQCanvas * arg0; // Dummy
+ TTQCanvas * arg0; // Dummy
- // We should now create an instance of the TQCanvasText object
+ // We should now create an instance of the TTQCanvasText object
- TQCanvasText *ret = new TQCanvasText(
+ TTQCanvasText *ret = new TTQCanvasText(
arg0 );
}
-KJS::Object QCanvasTextImp::QCanvasText_2( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasTextImp::TQCanvasText_2( KJS::ExecState *exec, const KJS::List &args )
{
- TQString arg0 = extractQString(exec, args, 0);
+ TTQString arg0 = extractTQString(exec, args, 0);
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();
- TQCanvas * arg1; // Dummy
+ TTQCanvas * arg1; // Dummy
- // We should now create an instance of the TQCanvasText object
+ // We should now create an instance of the TTQCanvasText object
- TQCanvasText *ret = new TQCanvasText(
+ TTQCanvasText *ret = new TTQCanvasText(
arg0,
arg1 );
@@ -181,25 +181,25 @@ KJS::Object QCanvasTextImp::QCanvasText_2( KJS::ExecState *exec, const KJS::List
}
-KJS::Object QCanvasTextImp::QCanvasText_3( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasTextImp::TQCanvasText_3( KJS::ExecState *exec, const KJS::List &args )
{
- TQString arg0 = extractQString(exec, args, 0);
+ TTQString arg0 = extractTQString(exec, args, 0);
- // Unsupported parameter QFont
+ // Unsupported parameter TQFont
return KJS::Object();
- TQFont arg1; // Dummy
+ TTQFont arg1; // Dummy
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();
- TQCanvas * arg2; // Dummy
+ TTQCanvas * arg2; // Dummy
- // We should now create an instance of the TQCanvasText object
+ // We should now create an instance of the TTQCanvasText object
- TQCanvasText *ret = new TQCanvasText(
+ TTQCanvasText *ret = new TTQCanvasText(
arg0,
arg1,
@@ -208,9 +208,9 @@ KJS::Object QCanvasTextImp::QCanvasText_3( KJS::ExecState *exec, const KJS::List
}
-KJS::Value QCanvasTextImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQCanvasTextImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QCanvasTextImp::toQCanvasText( self );
+ instance = TQCanvasTextImp::toTQCanvasText( self );
switch( id ) {
@@ -266,15 +266,15 @@ KJS::Value QCanvasTextImp::call( KJS::ExecState *exec, KJS::Object &self, const
break;
}
- TQString msg = i18n( "QCanvasTextImp has no method with id '%1'." ).arg( id );
+ TTQString msg = i18n( "TQCanvasTextImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasTextImp::setText_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::setText_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQString arg0 = extractQString(exec, args, 0);
+ TTQString arg0 = extractTQString(exec, args, 0);
instance->setText(
arg0 );
@@ -282,10 +282,10 @@ KJS::Value QCanvasTextImp::setText_5( KJS::ExecState *exec, KJS::Object &obj, co
}
-KJS::Value QCanvasTextImp::setFont_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::setFont_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQFont arg0 = extractQFont(exec, args, 0);
+ TTQFont arg0 = extractTQFont(exec, args, 0);
instance->setFont(
arg0 );
@@ -293,10 +293,10 @@ KJS::Value QCanvasTextImp::setFont_6( KJS::ExecState *exec, KJS::Object &obj, co
}
-KJS::Value QCanvasTextImp::setColor_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::setColor_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQColor arg0 = extractQColor(exec, args, 0);
+ TTQColor arg0 = extractTQColor(exec, args, 0);
instance->setColor(
arg0 );
@@ -304,32 +304,32 @@ KJS::Value QCanvasTextImp::setColor_7( KJS::ExecState *exec, KJS::Object &obj, c
}
-KJS::Value QCanvasTextImp::text_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::text_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQString ret;
+ TTQString ret;
ret = instance->text( );
return KJS::String( ret );
}
-KJS::Value QCanvasTextImp::font_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::font_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->font( );
- return KJS::Value(); // Returns 'QFont'
+ return KJS::Value(); // Returns 'TQFont'
}
-KJS::Value QCanvasTextImp::color_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::color_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->color( );
- return KJS::Value(); // Returns 'QColor'
+ return KJS::Value(); // Returns 'TQColor'
}
-KJS::Value QCanvasTextImp::moveBy_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::moveBy_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
double arg0 = extractDouble(exec, args, 0);
@@ -343,7 +343,7 @@ KJS::Value QCanvasTextImp::moveBy_11( KJS::ExecState *exec, KJS::Object &obj, co
}
-KJS::Value QCanvasTextImp::textFlags_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::textFlags_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -352,7 +352,7 @@ KJS::Value QCanvasTextImp::textFlags_12( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasTextImp::setTextFlags_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::setTextFlags_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -363,22 +363,22 @@ KJS::Value QCanvasTextImp::setTextFlags_13( KJS::ExecState *exec, KJS::Object &o
}
-KJS::Value QCanvasTextImp::boundingRect_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::boundingRect_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQRect ret;
+ TTQRect ret;
ret = instance->boundingRect( );
return convertToValue( exec, ret );
}
-KJS::Value QCanvasTextImp::collidesWith_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::collidesWith_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const TQCanvasItem *
return KJS::Value();
- const TQCanvasItem * arg0; // Dummy
+ const TTQCanvasItem * arg0; // Dummy
bool ret;
ret = instance->collidesWith(
@@ -387,7 +387,7 @@ KJS::Value QCanvasTextImp::collidesWith_15( KJS::ExecState *exec, KJS::Object &o
}
-KJS::Value QCanvasTextImp::rtti_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasTextImp::rtti_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -93,87 +93,87 @@ void QCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TQCanvasText pointer from an Object.
+ * Extract a TTQCanvasText pointer from an Object.
*/
@@ -93,87 +93,87 @@ void QCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();
@@ -363,22 +363,22 @@ KJS::Value QCanvasTextImp::setTextFlags_13( KJS::ExecState *exec, KJS::Object &o
{
- // Unsupported parameter const TQCanvasItem *
+ // Unsupported parameter const TTQCanvasItem *
return KJS::Value();